==> minetest-mod-character-creator_1.0.orig.tar.gz: character_creator-1.0/skins.lua <==
return {
	skin = {
		["Fair Skin"] = "cc_skin_fair.png",
		["Green Skin"] = "cc_skin_green.png",
		["Red Skin"] = "cc_skin_red.png",
		["Tanned Skin"] = "cc_skin_tanned.png",
		["White Skin"] = "cc_skin_white.png",
		["Black Skin"] = "cc_skin_black.png",
		["Dark Skin"] = "cc_skin_dark.png",
	},

	face = {
		["Human Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_human_fair_M.png",
				["Green Skin"] = "cc_face_human_green_M.png",
				["Red Skin"] = "cc_face_human_red_M.png",
				["Tanned Skin"] = "cc_face_human_tanned_M.png",
				["White Skin"] = "cc_face_human_white_M.png",
				["Black Skin"] = "cc_face_human_black_M.png",
				["Dark Skin"] = "cc_face_human_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_human_fair_F.png",
				["Green Skin"] = "cc_face_human_green_F.png",
				["Red Skin"] = "cc_face_human_red_F.png",
				["Tanned Skin"] = "cc_face_human_tanned_F.png",
				["White Skin"] = "cc_face_human_white_F.png",
				["Black Skin"] = "cc_face_human_black_F.png",
				["Dark Skin"] = "cc_face_human_dark_F.png",
			}
		},
		["Alien Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_alien_fair_M.png",
				["Green Skin"] = "cc_face_alien_green_M.png",
				["Red Skin"] = "cc_face_alien_red_M.png",
				["Tanned Skin"] = "cc_face_alien_tanned_M.png",
				["White Skin"] = "cc_face_alien_white_M.png",
				["Black Skin"] = "cc_face_alien_black_M.png",
				["Dark Skin"] = "cc_face_alien_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_alien_fair_F.png",
				["Green Skin"] = "cc_face_alien_green_F.png",
				["Red Skin"] = "cc_face_alien_red_F.png",
				["Tanned Skin"] = "cc_face_alien_tanned_F.png",
				["White Skin"] = "cc_face_alien_white_F.png",
				["Black Skin"] = "cc_face_alien_black_F.png",
				["Dark Skin"] = "cc_face_alien_dark_F.png",
			}
		},
		["Dwarven Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_dwarven_fair_M.png",
				["Green Skin"] = "cc_face_dwarven_green_M.png",
				["Red Skin"] = "cc_face_dwarven_red_M.png",
				["Tanned Skin"] = "cc_face_dwarven_tanned_M.png",
				["White Skin"] = "cc_face_dwarven_white_M.png",
				["Black Skin"] = "cc_face_dwarven_black_M.png",
				["Dark Skin"] = "cc_face_dwarven_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_dwarven_fair_F.png",
				["Green Skin"] = "cc_face_dwarven_green_F.png",
				["Red Skin"] = "cc_face_dwarven_red_F.png",
				["Tanned Skin"] = "cc_face_dwarven_tanned_F.png",
				["White Skin"] = "cc_face_dwarven_white_F.png",
				["Black Skin"] = "cc_face_dwarven_black_F.png",
				["Dark Skin"] = "cc_face_dwarven_dark_F.png",
			}
		},
		["Elven Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_elven_fair_M.png",
				["Green Skin"] = "cc_face_elven_green_M.png",
				["Red Skin"] = "cc_face_elven_red_M.png",
				["Tanned Skin"] = "cc_face_elven_tanned_M.png",
				["White Skin"] = "cc_face_elven_white_M.png",
				["Black Skin"] = "cc_face_elven_black_M.png",
				["Dark Skin"] = "cc_face_elven_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_elven_fair_F.png",
				["Green Skin"] = "cc_face_elven_green_F.png",
				["Red Skin"] = "cc_face_elven_red_F.png",
				["Tanned Skin"] = "cc_face_elven_tanned_F.png",
				["White Skin"] = "cc_face_elven_white_F.png",
				["Black Skin"] = "cc_face_elven_black_F.png",
				["Dark Skin"] = "cc_face_elven_dark_F.png",
			}
		}
	},

	hair = {
		["Brown Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_brown_M.png",
				["Short Hair"] = "cc_hair_short_brown_M.png",
				["Styled Hair"] = "cc_hair_special_brown_M.png",
				["Long Hair"] = "cc_hair_long_brown_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_brown_F.png",
				["Short Hair"] = "cc_hair_short_brown_F.png",
				["Styled Hair"] = "cc_hair_special_brown_F.png",
				["Long Hair"] = "cc_hair_long_brown_F.png",
			}
		},
		["Green Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_green_M.png",
				["Short Hair"] = "cc_hair_short_green_M.png",
				["Styled Hair"] = "cc_hair_special_green_M.png",
				["Long Hair"] = "cc_hair_long_green_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_green_F.png",
				["Short Hair"] = "cc_hair_short_green_F.png",
				["Styled Hair"] = "cc_hair_special_green_F.png",
				["Long Hair"] = "cc_hair_long_green_F.png",
			}
		},
		["Orange Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_orange_M.png",
				["Short Hair"] = "cc_hair_short_orange_M.png",
				["Styled Hair"] = "cc_hair_special_orange_M.png",
				["Long Hair"] = "cc_hair_long_orange_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_orange_F.png",
				["Short Hair"] = "cc_hair_short_orange_F.png",
				["Styled Hair"] = "cc_hair_special_orange_F.png",
				["Long Hair"] = "cc_hair_long_orange_F.png",
			}
		},
		["Purple Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_purple_M.png",
				["Short Hair"] = "cc_hair_short_purple_M.png",
				["Styled Hair"] = "cc_hair_special_purple_M.png",
				["Long Hair"] = "cc_hair_long_purple_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_purple_F.png",
				["Short Hair"] = "cc_hair_short_purple_F.png",
				["Styled Hair"] = "cc_hair_special_purple_F.png",
				["Long Hair"] = "cc_hair_long_purple_F.png",
			}
		},
		["Red Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_red_M.png",
				["Short Hair"] = "cc_hair_short_red_M.png",
				["Styled Hair"] = "cc_hair_special_red_M.png",
				["Long Hair"] = "cc_hair_long_red_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_red_F.png",
				["Short Hair"] = "cc_hair_short_red_F.png",
				["Styled Hair"] = "cc_hair_special_red_F.png",
				["Long Hair"] = "cc_hair_long_red_F.png",
			}
		},
		["White Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_white_M.png",
				["Short Hair"] = "cc_hair_short_white_M.png",
				["Styled Hair"] = "cc_hair_special_white_M.png",
				["Long Hair"] = "cc_hair_long_white_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_white_F.png",
				["Short Hair"] = "cc_hair_short_white_F.png",
				["Styled Hair"] = "cc_hair_special_white_F.png",
				["Long Hair"] = "cc_hair_long_white_F.png",
			}
		},
		["Black Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_black_M.png",
				["Short Hair"] = "cc_hair_short_black_M.png",
				["Styled Hair"] = "cc_hair_special_black_M.png",
				["Long Hair"] = "cc_hair_long_black_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_black_F.png",
				["Short Hair"] = "cc_hair_short_black_F.png",
				["Styled Hair"] = "cc_hair_special_black_F.png",
				["Long Hair"] = "cc_hair_long_black_F.png",
			}
		},
		["Blonde Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_blonde_M.png",
				["Short Hair"] = "cc_hair_short_blonde_M.png",
				["Styled Hair"] = "cc_hair_special_blonde_M.png",
				["Long Hair"] = "cc_hair_long_blonde_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_blonde_F.png",
				["Short Hair"] = "cc_hair_short_blonde_F.png",
				["Styled Hair"] = "cc_hair_special_blonde_F.png",
				["Long Hair"] = "cc_hair_long_blonde_F.png",
			}
		},
		["Blue Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_blue_M.png",
				["Short Hair"] = "cc_hair_short_blue_M.png",
				["Styled Hair"] = "cc_hair_special_blue_M.png",
				["Long Hair"] = "cc_hair_long_blue_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_blue_F.png",
				["Short Hair"] = "cc_hair_short_blue_F.png",
				["Styled Hair"] = "cc_hair_special_blue_F.png",
				["Long Hair"] = "cc_hair_long_blue_F.png",
			}
		}
	},

	hair_style = {
		["Medium Hair"] = "medium",
		["Short Hair"] = "short",
		["Styled Hair"] = "styled",
		["Long Hair"] = "long",
	},

	eyes = {
		["Blue Eyes"] = "cc_eyes_blue.png",
		["Brown Eyes"] = "cc_eyes_brown.png",
		["Green Eyes"] = "cc_eyes_green.png",
		["Orange Eyes"] = "cc_eyes_orange.png",
		["Purple Eyes"] = "cc_eyes_purple.png",
		["Red Eyes"] = "cc_eyes_red.png",
		["White Eyes"] = "cc_eyes_white.png",
		["Yellow Eyes"] = "cc_eyes_yellow.png",
		["Black Eyes"] = "cc_eyes_black.png",
	},

	tshirt = {
		["Green T-Shirt"] = "cc_tshirt_green.png",
		["Orange T-Shirt"] = "cc_tshirt_orange.png",
		["Purple T-Shirt"] = "cc_tshirt_purple.png",
		["Red T-Shirt"] = "cc_tshirt_red.png",
		["White T-Shirt"] = "cc_tshirt_white.png",
		["Yellow T-Shirt"] = "cc_tshirt_yellow.png",
		["Black T-Shirt"] = "cc_tshirt_black.png",
		["Blue T-Shirt"] = "cc_tshirt_blue.png",
	},

	pants = {
		["Blue Pants"] = "cc_pants_blue.png",
		["Green Pants"] = "cc_pants_green.png",
		["Orange Pants"] = "cc_pants_orange.png",
		["Purple Pants"] = "cc_pants_purple.png",
		["Red Pants"] = "cc_pants_red.png",
		["White Pants"] = "cc_pants_white.png",
		["Yellow Pants"] = "cc_pants_yellow.png",
		["Black Pants"] = "cc_pants_black.png",
	},

	shoes = {
		["Leather Shoes"] = "cc_shoes_leather.png",
		["Canvas Shoes"] = "cc_shoes_canvas.png",
		["Fur Shoes"] = "cc_shoes_fur.png",
	}
}

==> minetest-mod-character-creator_1.2.orig.tar.gz: character_creator-1.2/skins.lua <==
-- TODO: Check if the indices are backwards-compatible after "translation"
--local S = character_creator.S

character_creator.skins = {
	skin = {
		["Fair Skin"] = "cc_skin_fair.png",
		["Green Skin"] = "cc_skin_green.png",
		["Red Skin"] = "cc_skin_red.png",
		["Tanned Skin"] = "cc_skin_tanned.png",
		["White Skin"] = "cc_skin_white.png",
		["Black Skin"] = "cc_skin_black.png",
		["Dark Skin"] = "cc_skin_dark.png",
	},

	face = {
		["Human Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_human_fair_M.png",
				["Green Skin"] = "cc_face_human_green_M.png",
				["Red Skin"] = "cc_face_human_red_M.png",
				["Tanned Skin"] = "cc_face_human_tanned_M.png",
				["White Skin"] = "cc_face_human_white_M.png",
				["Black Skin"] = "cc_face_human_black_M.png",
				["Dark Skin"] = "cc_face_human_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_human_fair_F.png",
				["Green Skin"] = "cc_face_human_green_F.png",
				["Red Skin"] = "cc_face_human_red_F.png",
				["Tanned Skin"] = "cc_face_human_tanned_F.png",
				["White Skin"] = "cc_face_human_white_F.png",
				["Black Skin"] = "cc_face_human_black_F.png",
				["Dark Skin"] = "cc_face_human_dark_F.png",
			}
		},
		["Alien Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_alien_fair_M.png",
				["Green Skin"] = "cc_face_alien_green_M.png",
				["Red Skin"] = "cc_face_alien_red_M.png",
				["Tanned Skin"] = "cc_face_alien_tanned_M.png",
				["White Skin"] = "cc_face_alien_white_M.png",
				["Black Skin"] = "cc_face_alien_black_M.png",
				["Dark Skin"] = "cc_face_alien_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_alien_fair_F.png",
				["Green Skin"] = "cc_face_alien_green_F.png",
				["Red Skin"] = "cc_face_alien_red_F.png",
				["Tanned Skin"] = "cc_face_alien_tanned_F.png",
				["White Skin"] = "cc_face_alien_white_F.png",
				["Black Skin"] = "cc_face_alien_black_F.png",
				["Dark Skin"] = "cc_face_alien_dark_F.png",
			}
		},
		["Dwarven Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_dwarven_fair_M.png",
				["Green Skin"] = "cc_face_dwarven_green_M.png",
				["Red Skin"] = "cc_face_dwarven_red_M.png",
				["Tanned Skin"] = "cc_face_dwarven_tanned_M.png",
				["White Skin"] = "cc_face_dwarven_white_M.png",
				["Black Skin"] = "cc_face_dwarven_black_M.png",
				["Dark Skin"] = "cc_face_dwarven_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_dwarven_fair_F.png",
				["Green Skin"] = "cc_face_dwarven_green_F.png",
				["Red Skin"] = "cc_face_dwarven_red_F.png",
				["Tanned Skin"] = "cc_face_dwarven_tanned_F.png",
				["White Skin"] = "cc_face_dwarven_white_F.png",
				["Black Skin"] = "cc_face_dwarven_black_F.png",
				["Dark Skin"] = "cc_face_dwarven_dark_F.png",
			}
		},
		["Elven Face"] = {
			["Male"] = {
				["Fair Skin"] = "cc_face_elven_fair_M.png",
				["Green Skin"] = "cc_face_elven_green_M.png",
				["Red Skin"] = "cc_face_elven_red_M.png",
				["Tanned Skin"] = "cc_face_elven_tanned_M.png",
				["White Skin"] = "cc_face_elven_white_M.png",
				["Black Skin"] = "cc_face_elven_black_M.png",
				["Dark Skin"] = "cc_face_elven_dark_M.png",
			},
			["Female"] = {
				["Fair Skin"] = "cc_face_elven_fair_F.png",
				["Green Skin"] = "cc_face_elven_green_F.png",
				["Red Skin"] = "cc_face_elven_red_F.png",
				["Tanned Skin"] = "cc_face_elven_tanned_F.png",
				["White Skin"] = "cc_face_elven_white_F.png",
				["Black Skin"] = "cc_face_elven_black_F.png",
				["Dark Skin"] = "cc_face_elven_dark_F.png",
			}
		}
	},

	hair = {
		["Brown Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_brown_M.png",
				["Short Hair"] = "cc_hair_short_brown_M.png",
				["Styled Hair"] = "cc_hair_special_brown_M.png",
				["Long Hair"] = "cc_hair_long_brown_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_brown_F.png",
				["Short Hair"] = "cc_hair_short_brown_F.png",
				["Styled Hair"] = "cc_hair_special_brown_F.png",
				["Long Hair"] = "cc_hair_long_brown_F.png",
			}
		},
		["Green Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_green_M.png",
				["Short Hair"] = "cc_hair_short_green_M.png",
				["Styled Hair"] = "cc_hair_special_green_M.png",
				["Long Hair"] = "cc_hair_long_green_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_green_F.png",
				["Short Hair"] = "cc_hair_short_green_F.png",
				["Styled Hair"] = "cc_hair_special_green_F.png",
				["Long Hair"] = "cc_hair_long_green_F.png",
			}
		},
		["Orange Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_orange_M.png",
				["Short Hair"] = "cc_hair_short_orange_M.png",
				["Styled Hair"] = "cc_hair_special_orange_M.png",
				["Long Hair"] = "cc_hair_long_orange_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_orange_F.png",
				["Short Hair"] = "cc_hair_short_orange_F.png",
				["Styled Hair"] = "cc_hair_special_orange_F.png",
				["Long Hair"] = "cc_hair_long_orange_F.png",
			}
		},
		["Purple Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_purple_M.png",
				["Short Hair"] = "cc_hair_short_purple_M.png",
				["Styled Hair"] = "cc_hair_special_purple_M.png",
				["Long Hair"] = "cc_hair_long_purple_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_purple_F.png",
				["Short Hair"] = "cc_hair_short_purple_F.png",
				["Styled Hair"] = "cc_hair_special_purple_F.png",
				["Long Hair"] = "cc_hair_long_purple_F.png",
			}
		},
		["Red Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_red_M.png",
				["Short Hair"] = "cc_hair_short_red_M.png",
				["Styled Hair"] = "cc_hair_special_red_M.png",
				["Long Hair"] = "cc_hair_long_red_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_red_F.png",
				["Short Hair"] = "cc_hair_short_red_F.png",
				["Styled Hair"] = "cc_hair_special_red_F.png",
				["Long Hair"] = "cc_hair_long_red_F.png",
			}
		},
		["White Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_white_M.png",
				["Short Hair"] = "cc_hair_short_white_M.png",
				["Styled Hair"] = "cc_hair_special_white_M.png",
				["Long Hair"] = "cc_hair_long_white_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_white_F.png",
				["Short Hair"] = "cc_hair_short_white_F.png",
				["Styled Hair"] = "cc_hair_special_white_F.png",
				["Long Hair"] = "cc_hair_long_white_F.png",
			}
		},
		["Black Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_black_M.png",
				["Short Hair"] = "cc_hair_short_black_M.png",
				["Styled Hair"] = "cc_hair_special_black_M.png",
				["Long Hair"] = "cc_hair_long_black_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_black_F.png",
				["Short Hair"] = "cc_hair_short_black_F.png",
				["Styled Hair"] = "cc_hair_special_black_F.png",
				["Long Hair"] = "cc_hair_long_black_F.png",
			}
		},
		["Blonde Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_blonde_M.png",
				["Short Hair"] = "cc_hair_short_blonde_M.png",
				["Styled Hair"] = "cc_hair_special_blonde_M.png",
				["Long Hair"] = "cc_hair_long_blonde_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_blonde_F.png",
				["Short Hair"] = "cc_hair_short_blonde_F.png",
				["Styled Hair"] = "cc_hair_special_blonde_F.png",
				["Long Hair"] = "cc_hair_long_blonde_F.png",
			}
		},
		["Blue Hair"] = {
			["Male"] = {
				["Medium Hair"] = "cc_hair_medium_blue_M.png",
				["Short Hair"] = "cc_hair_short_blue_M.png",
				["Styled Hair"] = "cc_hair_special_blue_M.png",
				["Long Hair"] = "cc_hair_long_blue_M.png",
			},
			["Female"] = {
				["Medium Hair"] = "cc_hair_medium_blue_F.png",
				["Short Hair"] = "cc_hair_short_blue_F.png",
				["Styled Hair"] = "cc_hair_special_blue_F.png",
				["Long Hair"] = "cc_hair_long_blue_F.png",
			}
		}
	},

	hair_style = {
		["Medium Hair"] = "medium",
		["Short Hair"] = "short",
		["Styled Hair"] = "styled",
		["Long Hair"] = "long",
	},

	eyes = {
		["Blue Eyes"] = "cc_eyes_blue.png",
		["Brown Eyes"] = "cc_eyes_brown.png",
		["Green Eyes"] = "cc_eyes_green.png",
		["Orange Eyes"] = "cc_eyes_orange.png",
		["Purple Eyes"] = "cc_eyes_purple.png",
		["Red Eyes"] = "cc_eyes_red.png",
		["White Eyes"] = "cc_eyes_white.png",
		["Yellow Eyes"] = "cc_eyes_yellow.png",
		["Black Eyes"] = "cc_eyes_black.png",
	},

	tshirt = {
		["Green T-Shirt"] = "cc_tshirt_green.png",
		["Orange T-Shirt"] = "cc_tshirt_orange.png",
		["Purple T-Shirt"] = "cc_tshirt_purple.png",
		["Red T-Shirt"] = "cc_tshirt_red.png",
		["White T-Shirt"] = "cc_tshirt_white.png",
		["Yellow T-Shirt"] = "cc_tshirt_yellow.png",
		["Black T-Shirt"] = "cc_tshirt_black.png",
		["Blue T-Shirt"] = "cc_tshirt_blue.png",
		["Brown Vest"] = "cc_vest_brown.png",
		["Green Vest"] = "cc_vest_green.png",
		["Blue Vest"] = "cc_vest_blue.png",
		["Brown Shirt"] = "cc_shirt_canvas_brown.png",
		["Green Shirt"] = "cc_shirt_canvas_green.png",
		["Blue Shirt"] = "cc_shirt_canvas_blue.png",
	},

	pants = {
		["Blue Pants"] = "cc_pants_blue.png",
		["Green Pants"] = "cc_pants_green.png",
		["Orange Pants"] = "cc_pants_orange.png",
		["Purple Pants"] = "cc_pants_purple.png",
		["Red Pants"] = "cc_pants_red.png",
		["White Pants"] = "cc_pants_white.png",
		["Yellow Pants"] = "cc_pants_yellow.png",
		["Black Pants"] = "cc_pants_black.png",
		["Brown Canvas Pants"] = "cc_pants_canvas_brown.png",
		["Green Canvas Pants"] = "cc_pants_canvas_green.png",
		["Blue Canvas Pants"] = "cc_pants_canvas_blue.png",
	},

	shoes = {
		["Leather Shoes"] = "cc_shoes_leather.png",
		["Canvas Shoes"] = "cc_shoes_canvas.png",
		["Fur Shoes"] = "cc_shoes_fur.png",
		["Brown Shoes"] = "cc_shoes_brown.png",
		["Green Shoes"] = "cc_shoes_green.png",
		["Blue Shoes"] = "cc_shoes_blue.png",
		["Black Shoes"] = "cc_shoes_black.png",
	}
}
